from argparse import ArgumentParser, RawTextHelpFormatter
import fitz
import sys

# pip install PyMuPDF

try:
    from PySide6.QtCore import QLibraryInfo, qVersion
    from PySide6.QtGui import QImage, QPixmap
    from PySide6.QtWidgets import QApplication, QWidget, QGraphicsPixmapItem, QLabel
except ImportError:
    from PySide2.QtCore import QLibraryInfo, qVersion
    from PySide2.QtGui import QImage, QPixmap
    from PySide2.QtWidgets import QApplication, QWidget, QGraphicsPixmapItem, QLabel


if __name__ == "__main__":
    print('Python {}.{}'.format(sys.version_info[0], sys.version_info[1]))
    print(QLibraryInfo.build())

    argument_parser = ArgumentParser(description='pyside1563',
                                     formatter_class=RawTextHelpFormatter)
    argument_parser.add_argument("files", help="Files",
                                 nargs='+', type=str)
    argument_parser.add_argument("--convert", '-c',
                                 action='store_true', help="Convert to RGB32")

    options = argument_parser.parse_args()

    app = QApplication(sys.argv)

    doc = fitz.open(options.files[0])
    pagenum = 1
    page = doc[pagenum]

    pix = page.get_pixmap()
    doc.close()

    print('w=', pix.width, 'h=', pix.height, 'stride=', pix.stride)
    if len(options.files) > 1:
        fn = options.files[1]
        with open(fn, "wb") as f:
            f.write(pix.samples)
            print('wrote ', fn)

    print('samples=', type(pix.samples))
    qimage = QImage(pix.samples, pix.width, pix.height, pix.stride,
                    QImage.Format_RGB888)
    print('orig', qimage)
    sys.stdout.flush()
    if options.convert:
        qimage = qimage.convertToFormat(QImage.Format_RGB32)
        print('converted', qimage)
        sys.stdout.flush()

    qpix = QPixmap.fromImage(qimage)
    print(qpix)
    sys.stdout.flush()

    label = QLabel()
    label.setPixmap(qpix)
    label.show()
    app.exec_()
